@@ -6,7 +6,7 @@ from lesscode.web.router_mapping import Handler, GetMapping
 from tornado.options import options
 
 
-@Handler("/swagger_interface")
+@Handler("/swagger_interface", desc="swagger接口")
 class SwaggerInterfaceDocHandler(BaseHandler):
 
     @GetMapping(title="获取swagger接口文档")
